==> ejc-analysis-api-3.0.0-20230712.091259-67-sources.jar: com/ejianc/business/analysis/vo/AuthenticRightVO.java <==
package com.ejianc.business.analysis.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 项目确权情况分析
 * 
 * @author generator
 * 
 */
public class AuthenticRightVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 项目组织id
    private String orgCode; // 项目组织编码
    private String orgName; // 组织名称
    private Long projectDepartmentId; // 项目部id
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer projectStatus; // 项目状态
    private String projectStatusName;//项目状态名称
    private Date reportingMonth; // 报表日期
    private BigDecimal notarizeProductYear; // 业主确认产值（本年）
    private BigDecimal realProductYear; // 实际完成产值（本年）
    private BigDecimal actualCostYear; // 实际成本（本年）
    private BigDecimal notarizeProductTotal; // 业主确认产值（开累）
    private BigDecimal realProductTotal; // 实际完成产值（开累）
    private BigDecimal actualCostTotal; // 实际成本（开累）
    private Date projectCreateTime; // 项目创建日期
    private BigDecimal notarizeRate; // 年确认率
    private BigDecimal authenticRightRate; // 年确权率
    private BigDecimal notarizeRateTotal; // 开累确认率
    private BigDecimal authenticRightRateTotal; // 开累确权率
    private Date projectUnitCreateTime; // 工程计量时间
    private Date costAnalyseCreateTime; // 成本分析时间
    private String memo; // 备注
    private String number; // 序号

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(Date reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public BigDecimal getNotarizeProductYear() {
        return notarizeProductYear;
    }

    public void setNotarizeProductYear(BigDecimal notarizeProductYear) {
        this.notarizeProductYear = notarizeProductYear;
    }
    public BigDecimal getRealProductYear() {
        return realProductYear;
    }

    public void setRealProductYear(BigDecimal realProductYear) {
        this.realProductYear = realProductYear;
    }
    public BigDecimal getActualCostYear() {
        return actualCostYear;
    }

    public void setActualCostYear(BigDecimal actualCostYear) {
        this.actualCostYear = actualCostYear;
    }
    public BigDecimal getNotarizeProductTotal() {
        return notarizeProductTotal;
    }

    public void setNotarizeProductTotal(BigDecimal notarizeProductTotal) {
        this.notarizeProductTotal = notarizeProductTotal;
    }
    public BigDecimal getRealProductTotal() {
        return realProductTotal;
    }

    public void setRealProductTotal(BigDecimal realProductTotal) {
        this.realProductTotal = realProductTotal;
    }
    public BigDecimal getActualCostTotal() {
        return actualCostTotal;
    }

    public void setActualCostTotal(BigDecimal actualCostTotal) {
        this.actualCostTotal = actualCostTotal;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public BigDecimal getNotarizeRate() {
        return notarizeRate;
    }

    public void setNotarizeRate(BigDecimal notarizeRate) {
        this.notarizeRate = notarizeRate;
    }
    public BigDecimal getNotarizeRateTotal() {
        return notarizeRateTotal;
    }

    public void setNotarizeRateTotal(BigDecimal notarizeRateTotal) {
        this.notarizeRateTotal = notarizeRateTotal;
    }
    public BigDecimal getAuthenticRightRate() {
        return authenticRightRate;
    }

    public void setAuthenticRightRate(BigDecimal authenticRightRate) {
        this.authenticRightRate = authenticRightRate;
    }
    public BigDecimal getAuthenticRightRateTotal() {
        return authenticRightRateTotal;
    }

    public void setAuthenticRightRateTotal(BigDecimal authenticRightRateTotal) {
        this.authenticRightRateTotal = authenticRightRateTotal;
    }
    public Date getProjectUnitCreateTime() {
        return projectUnitCreateTime;
    }

    public void setProjectUnitCreateTime(Date projectUnitCreateTime) {
        this.projectUnitCreateTime = projectUnitCreateTime;
    }
    public Date getCostAnalyseCreateTime() {
        return costAnalyseCreateTime;
    }

    public void setCostAnalyseCreateTime(Date costAnalyseCreateTime) {
        this.costAnalyseCreateTime = costAnalyseCreateTime;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }
}

==> ejc-analysis-api-3.0.0-20250813.020136-305-sources.jar: com/ejianc/business/analysis/vo/AuthenticRightVO.java <==
package com.ejianc.business.analysis.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 项目确权情况分析
 * 
 * @author generator
 * 
 */
public class AuthenticRightVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 项目组织id
    private String orgCode; // 项目组织编码
    private String orgName; // 组织名称
    private Long projectDepartmentId; // 项目部id
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer projectStatus; // 项目状态
    private String projectStatusName;//项目状态名称
    private Date reportingMonth; // 报表日期
    private BigDecimal notarizeProductYear; // 业主确认产值（本年）
    private BigDecimal realProductYear; // 实际完成产值（本年）
    private BigDecimal actualCostYear; // 实际成本（本年）
    private BigDecimal notarizeProductTotal; // 业主确认产值（开累）
    private BigDecimal realProductTotal; // 实际完成产值（开累）
    private BigDecimal actualCostTotal; // 实际成本（开累）
    private Date projectCreateTime; // 项目创建日期
    private BigDecimal notarizeRate; // 年确认率
    private BigDecimal authenticRightRate; // 年确权率
    private BigDecimal notarizeRateTotal; // 开累确认率
    private BigDecimal authenticRightRateTotal; // 开累确权率
    private Date projectUnitCreateTime; // 工程计量时间
    private Date costAnalyseCreateTime; // 成本分析时间
    private String memo; // 备注
    private String number; // 序号
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(Date reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public BigDecimal getNotarizeProductYear() {
        return notarizeProductYear;
    }

    public void setNotarizeProductYear(BigDecimal notarizeProductYear) {
        this.notarizeProductYear = notarizeProductYear;
    }
    public BigDecimal getRealProductYear() {
        return realProductYear;
    }

    public void setRealProductYear(BigDecimal realProductYear) {
        this.realProductYear = realProductYear;
    }
    public BigDecimal getActualCostYear() {
        return actualCostYear;
    }

    public void setActualCostYear(BigDecimal actualCostYear) {
        this.actualCostYear = actualCostYear;
    }
    public BigDecimal getNotarizeProductTotal() {
        return notarizeProductTotal;
    }

    public void setNotarizeProductTotal(BigDecimal notarizeProductTotal) {
        this.notarizeProductTotal = notarizeProductTotal;
    }
    public BigDecimal getRealProductTotal() {
        return realProductTotal;
    }

    public void setRealProductTotal(BigDecimal realProductTotal) {
        this.realProductTotal = realProductTotal;
    }
    public BigDecimal getActualCostTotal() {
        return actualCostTotal;
    }

    public void setActualCostTotal(BigDecimal actualCostTotal) {
        this.actualCostTotal = actualCostTotal;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public BigDecimal getNotarizeRate() {
        return notarizeRate;
    }

    public void setNotarizeRate(BigDecimal notarizeRate) {
        this.notarizeRate = notarizeRate;
    }
    public BigDecimal getNotarizeRateTotal() {
        return notarizeRateTotal;
    }

    public void setNotarizeRateTotal(BigDecimal notarizeRateTotal) {
        this.notarizeRateTotal = notarizeRateTotal;
    }
    public BigDecimal getAuthenticRightRate() {
        return authenticRightRate;
    }

    public void setAuthenticRightRate(BigDecimal authenticRightRate) {
        this.authenticRightRate = authenticRightRate;
    }
    public BigDecimal getAuthenticRightRateTotal() {
        return authenticRightRateTotal;
    }

    public void setAuthenticRightRateTotal(BigDecimal authenticRightRateTotal) {
        this.authenticRightRateTotal = authenticRightRateTotal;
    }
    public Date getProjectUnitCreateTime() {
        return projectUnitCreateTime;
    }

    public void setProjectUnitCreateTime(Date projectUnitCreateTime) {
        this.projectUnitCreateTime = projectUnitCreateTime;
    }
    public Date getCostAnalyseCreateTime() {
        return costAnalyseCreateTime;
    }

    public void setCostAnalyseCreateTime(Date costAnalyseCreateTime) {
        this.costAnalyseCreateTime = costAnalyseCreateTime;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }
}
